pub type SubmissionIndicesOf<T> = BoundedVec<(ElectionScore, BlockNumberFor<T>, u32), <T as Config>::SignedMaxSubmissions>;Expand description
Always sorted vector of a score, submitted at the given block number, which can be found at the
given index (u32) of the SignedSubmissionsMap.
Aliased Type
struct SubmissionIndicesOf<T>(/* private fields */);